import { elements, html, ref, slotted, when } from "@microsoft/fast-element";
import { endSlotTemplate, startSlotTemplate, staticallyCompose, tagFor, } from "@microsoft/fast-foundation";
import { Interactivity } from "@adaptive-web/adaptive-ui";
import { composeFlipper } from "../flipper/index.js";
/**
 * @public
 */
export const HorizontalScrollConditions = {};
/**
 * @public
 */
export const HorizontalScrollParts = {
    scrollArea: "scroll-area",
    scrollView: "scroll-view",
    content: "content",
    scrollPrevious: "scroll-previous",
    previousFlipper: "previous-flipper",
    scrollNext: "scroll-next",
    nextFlipper: "next-flipper",
};
/**
 * @public
 */
export const HorizontalScrollAnatomy = {
    interactivity: Interactivity.never,
    conditions: HorizontalScrollConditions,
    parts: HorizontalScrollParts,
};
/**
 * Default Horizontal Scroll template, {@link @microsoft/fast-foundation#horizontalScrollTemplate}.
 * @public
 */
export const template = (ds) => {
    const options = {
        flipper: composeFlipper(ds),
    };
    const flipperTag = html.partial(tagFor(options.flipper));
    return html `
            <template @keyup="${(x, c) => x.keyupHandler(c.event)}">
                ${startSlotTemplate(options)}
                <div class="scroll-area" part="scroll-area">
                    <div class="scroll-view" part="scroll-view" @scroll="${(x) => x.scrolled()}" ${ref("scrollContainer")}>
                        <div class="content" part="content" ${ref("content")}>
                            <slot
                                ${slotted({
        property: "scrollItems",
        filter: elements(),
    })}
                            ></slot>
                        </div>
                    </div>
                    ${when((x) => x.view !== "mobile", html `
                            <div class="scroll-previous" part="scroll-previous" ${ref("previousFlipperContainer")}>
                                <slot name="previous-flipper">
                                    ${staticallyCompose(options.previousFlipper ??
        html `
                                                <${flipperTag}
                                                    part="previous-flipper"
                                                    @click="${(x) => x.scrollToPrevious()}"
                                                    direction="previous"
                                                    aria-hidden="${(x) => x.flippersHiddenFromAT}"
                                                ></${flipperTag}>
                                            `)}
                                </slot>
                            </div>
                            <div class="scroll-next" part="scroll-next" ${ref("nextFlipperContainer")}>
                                <slot name="next-flipper">
                                    ${staticallyCompose(options.nextFlipper ??
        html `
                                                <${flipperTag}
                                                    part="next-flipper"
                                                    @click="${(x) => x.scrollToNext()}"
                                                    aria-hidden="${(x) => x.flippersHiddenFromAT}"
                                                ></${flipperTag}>
                                            `)}
                                </slot>
                            </div>
                        `)}
                </div>
                ${endSlotTemplate(options)}
            </template>
        `;
};
//# sourceMappingURL=horizontal-scroll.template.js.map