import { FASTMenu, MenuItemRole } from "@microsoft/fast-foundation";
import { AdaptiveMenuItem } from "../menu-item/menu-item.js";
/**
 * The Adaptive version of Menu. Extends {@link @microsoft/fast-foundation#FASTMenu}.
 *
 * @public
 */
export class AdaptiveMenu extends FASTMenu {
    static elementIndent(el) {
        const role = el.getAttribute("role");
        const startSlot = el.querySelector("[slot=start]");
        return {
            hasControl: role !== MenuItemRole.menuitem,
            hasStart: startSlot !== null,
        };
    }
    setItems() {
        super.setItems();
        const items = this.menuItems?.filter(this.isMenuItemElement);
        items?.forEach((item) => {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            const indentInfo = items.reduce((accum, current) => {
                const elementValue = AdaptiveMenu.elementIndent(current);
                return {
                    hasControl: accum.hasControl || elementValue.hasControl,
                    hasStart: accum.hasStart || elementValue.hasStart,
                };
            }, {
                hasControl: false,
                hasStart: false,
            });
            const indent = indentInfo.hasControl && indentInfo.hasStart
                ? 2
                : indentInfo.hasControl || indentInfo.hasStart
                    ? 1
                    : 0;
            if (item instanceof AdaptiveMenuItem) {
                item.startColumnCount = indent;
            }
        });
    }
}
//# sourceMappingURL=menu.js.map