import { DesignSystem } from "../../design-system.js";
import { componentBaseStyles, svgIconStyles } from '../../styles/styles.js';
import { AdaptiveNumberField } from "./number-field.js";
import { aestheticStyles, templateStyles } from "./number-field.styles.js";
import { NumberFieldAnatomy, NumberFieldStatics, template } from "./number-field.template.js";
const defaultStyles = [componentBaseStyles, templateStyles, svgIconStyles, aestheticStyles];
/**
 * @public
 */
export function composeNumberField(ds, options) {
    if (options?.statics) {
        if (!ds.statics.has(NumberFieldStatics.stepDown)) {
            ds.statics.set(NumberFieldStatics.stepDown, options.statics[NumberFieldStatics.stepDown]);
        }
        if (!ds.statics.has(NumberFieldStatics.stepUp)) {
            ds.statics.set(NumberFieldStatics.stepUp, options.statics[NumberFieldStatics.stepUp]);
        }
    }
    const styles = DesignSystem.assembleStyles(defaultStyles, NumberFieldAnatomy, options);
    return AdaptiveNumberField.compose({
        name: `${ds.prefix}-number-field`,
        template: options?.template?.(ds) ?? template(ds),
        styles,
        registry: ds.registry,
        elementOptions: options?.elementOptions,
        shadowOptions: options?.shadowOptions
    });
}
//# sourceMappingURL=number-field.compose.js.map