import { html, when } from "@microsoft/fast-element";
import { staticallyCompose } from "@microsoft/fast-foundation";
import { Interactivity } from "@adaptive-web/adaptive-ui";
/**
 * @public
 */
export const ProgressRingConditions = {};
/**
 * @public
 */
export const ProgressRingParts = {
    indicator: "indicator",
    determinate: "determinate",
    indeterminate: "indeterminate",
};
/**
 * @public
 */
export const ProgressRingAnatomy = {
    interactivity: Interactivity.never,
    conditions: ProgressRingConditions,
    parts: ProgressRingParts,
};
const progressRingIndicatorTemplate = html `
    <svg viewBox="0 0 16 16" class="progress">
        <circle class="background" part="background" cx="8px" cy="8px" r="7px"></circle>
        <circle class="indicator" part="indicator" cx="8px" cy="8px" r="7px"></circle>
    </svg>
`;
/**
 * Default Progress template, {@link @microsoft/fast-foundation#progressTemplate}.
 * @public
 */
export const template = (ds) => {
    const options = {
        determinateIndicator: progressRingIndicatorTemplate,
        indeterminateIndicator: progressRingIndicatorTemplate,
    };
    return html `
            <template
                role="progressbar"
                aria-valuenow="${x => x.value}"
                aria-valuemin="${x => x.min}"
                aria-valuemax="${x => x.max}"
            >
                ${when(x => typeof x.value === "number", html `
                        <span
                            class="determinate"
                            part="determinate"
                            style="--percent-complete: ${x => x.percentComplete}"
                        >
                            <slot name="determinate">
                                ${staticallyCompose(options.determinateIndicator)}
                            </slot>
                        </span>
                    `)}
                ${when(x => typeof x.value !== "number", html `
                        <span class="indeterminate" part="indeterminate">
                            <slot name="indeterminate">
                                ${staticallyCompose(options.indeterminateIndicator)}
                            </slot>
                        </span>
                    `)}
            </template>
        `;
};
//# sourceMappingURL=progress-ring.template.js.map